@@ -10,22 +10,22 @@ use warnings;
 use warnings::register;
 
 use vars qw($VERSION $DATE $FILE );
-$VERSION = '0.02';
-$DATE = '2003/07/27';
+$VERSION = '0.03';
+$DATE = '2003/09/15';
 $FILE = __FILE__;
 
 use vars qw(%INVENTORY);
 %INVENTORY = (
-    'lib/Docs/Site_SVD/Text_Column.pm' => [qw(0.02 2003/07/27), 'revised 0.01'],
-    'MANIFEST' => [qw(0.02 2003/07/27), 'generated, replaces 0.01'],
-    'Makefile.PL' => [qw(0.02 2003/07/27), 'generated, replaces 0.01'],
-    'README' => [qw(0.02 2003/07/27), 'generated, replaces 0.01'],
+    'lib/Docs/Site_SVD/Text_Column.pm' => [qw(0.03 2003/09/15), 'revised 0.02'],
+    'MANIFEST' => [qw(0.03 2003/09/15), 'generated, replaces 0.02'],
+    'Makefile.PL' => [qw(0.03 2003/09/15), 'generated, replaces 0.02'],
+    'README' => [qw(0.03 2003/09/15), 'generated, replaces 0.02'],
     'lib/Text/Column.pm' => [qw(1.09 2003/07/05), 'unchanged'],
-    't/Text/Column.d' => [qw(0.04 2003/07/27), 'revised 0.03'],
+    't/Text/Column.d' => [qw(0.01 2003/07/27), 'unchanged'],
     't/Text/Column.pm' => [qw(0.01 2003/07/05), 'unchanged'],
-    't/Text/Column.t' => [qw(0.04 2003/07/27), 'revised 0.03'],
-    'tlib/File/Package.pm' => [qw(1.1 2003/07/27), 'new'],
-    'tlib/Test/Tech.pm' => [qw(1.11 2003/07/27), 'new'],
+    't/Text/Column.t' => [qw(0.05 2003/09/15), 'revised 0.04'],
+    'tlib/File/Package.pm' => [qw(1.12 2003/09/15), 'revised 1.1'],
+    'tlib/Test/Tech.pm' => [qw(1.13 2003/09/15), 'revised 1.11'],
 
 );
 
@@ -52,11 +52,11 @@ use vars qw(%INVENTORY);
 
  Text::Column - Format tables from hashes and arrays suitable for PODs
 
- Revision: A
+ Revision: B
 
- Version: 0.02
+ Version: 0.03
 
- Date: 2003/07/27
+ Date: 2003/09/15
 
  Prepared for: General Public 
 
@@ -102,7 +102,7 @@ by formatting raw array and hash data into tables for inclusion in PODS
 
 =head2 1.3 Document overview.
 
-This document releases Text::Column version 0.02
+This document releases Text::Column version 0.03
 providing a description of the inventory, installation
 instructions and other information necessary to
 utilize and track this release.
@@ -118,8 +118,8 @@ system file specification.
 This document releases the file found
 at the following repository(s):
 
-   http://www.softwarediamonds/packages/Text-Column-0.02
-   http://www.perl.com/CPAN-local/authors/id/S/SO/SOFTDIA/Text-Column-0.02
+   http://www.softwarediamonds/packages/Text-Column-0.03
+   http://www.perl.com/CPAN-local/authors/id/S/SO/SOFTDIA/Text-Column-0.03
 
 
 Restrictions regarding duplication and license provisions
@@ -187,16 +187,16 @@ consists of the following files:
 
  file                                                         version date       comment
  ------------------------------------------------------------ ------- ---------- ------------------------
- lib/Docs/Site_SVD/Text_Column.pm                             0.02    2003/07/27 revised 0.01
- MANIFEST                                                     0.02    2003/07/27 generated, replaces 0.01
- Makefile.PL                                                  0.02    2003/07/27 generated, replaces 0.01
- README                                                       0.02    2003/07/27 generated, replaces 0.01
+ lib/Docs/Site_SVD/Text_Column.pm                             0.03    2003/09/15 revised 0.02
+ MANIFEST                                                     0.03    2003/09/15 generated, replaces 0.02
+ Makefile.PL                                                  0.03    2003/09/15 generated, replaces 0.02
+ README                                                       0.03    2003/09/15 generated, replaces 0.02
  lib/Text/Column.pm                                           1.09    2003/07/05 unchanged
- t/Text/Column.d                                              0.04    2003/07/27 revised 0.03
+ t/Text/Column.d                                              0.01    2003/07/27 unchanged
  t/Text/Column.pm                                             0.01    2003/07/05 unchanged
- t/Text/Column.t                                              0.04    2003/07/27 revised 0.03
- tlib/File/Package.pm                                         1.1     2003/07/27 new
- tlib/Test/Tech.pm                                            1.11    2003/07/27 new
+ t/Text/Column.t                                              0.05    2003/09/15 revised 0.04
+ tlib/File/Package.pm                                         1.12    2003/09/15 revised 1.1
+ tlib/Test/Tech.pm                                            1.13    2003/09/15 revised 1.11
 
 
 =head2 3.3 Changes
@@ -251,6 +251,13 @@ The test of this module will precede immediately.
 The test support files in the tlib directory will vanish after
 the installtion.
 
+=item Text-Column-0.03
+
+Recreate distribution file 
+with Archive::TarGzip 0.02 that uses mode 777 for directories instead of 666. Started to get
+emails from Unix installers about untar not being able to change to
+a directory with mode of 666.
+
 =back
 
 =head2 3.4 Adaptation data.
@@ -284,8 +291,8 @@ Follow the instructions for the the chosen installation software.
 
 The distribution file is at the following respositories:
 
-   http://www.softwarediamonds/packages/Text-Column-0.02
-   http://www.perl.com/CPAN-local/authors/id/S/SO/SOFTDIA/Text-Column-0.02
+   http://www.softwarediamonds/packages/Text-Column-0.03
+   http://www.perl.com/CPAN-local/authors/id/S/SO/SOFTDIA/Text-Column-0.03
 
 
 =item Prerequistes.
@@ -401,11 +408,11 @@ __DATA__
 DISTNAME: Text-Column^
 REPOSITORY_DIR: packages^
 
-VERSION : 0.02^
+VERSION : 0.03^
 FREEZE: 1^
 PREVIOUS_DISTNAME:  ^
-PREVIOUS_RELEASE: 0.01^
-REVISION: A^
+PREVIOUS_RELEASE: 0.02^
+REVISION: B^
 
 
 AUTHOR  : SoftwareDiamonds.com E<lt>support@SoftwareDiamonds.comE<gt>^
@@ -491,8 +498,14 @@ The test of this module will precede immediately.
 The test support files in the tlib directory will vanish after
 the installtion.
 
-\=back
+\=item Text-Column-0.03
 
+Recreate distribution file 
+with Archive::TarGzip 0.02 that uses mode 777 for directories instead of 666. Started to get
+emails from Unix installers about untar not being able to change to
+a directory with mode of 666.
+
+\=back
 
 ^
 
